summaryrefslogtreecommitdiffstats
path: root/vtysh
diff options
context:
space:
mode:
authorDonald Sharp <sharpd@cumulusnetworks.com>2017-02-09 15:53:46 +0100
committerDonald Sharp <sharpd@cumulusnetworks.com>2017-02-09 15:53:46 +0100
commit305e9740fff1be7e8b66d0ba6fdbaece35a18524 (patch)
tree477810667139d8c1b8fea8ec3cc7eee7d544a45d /vtysh
parentMerge pull request #189 from opensourcerouting/config-write-sync (diff)
parentMerge pull request #190 from opensourcerouting/config-write-sync-stable (diff)
downloadfrr-305e9740fff1be7e8b66d0ba6fdbaece35a18524.tar.xz
frr-305e9740fff1be7e8b66d0ba6fdbaece35a18524.zip
Merge remote-tracking branch 'origin/stable/2.0'
Diffstat (limited to 'vtysh')
-rw-r--r--vtysh/vtysh.c2
-rw-r--r--vtysh/vtysh_main.c6
2 files changed, 4 insertions, 4 deletions
diff --git a/vtysh/vtysh.c b/vtysh/vtysh.c
index bc95dbb13..6427b8c16 100644
--- a/vtysh/vtysh.c
+++ b/vtysh/vtysh.c
@@ -2550,7 +2550,7 @@ DEFUN (vtysh_write_memory,
fprintf (stdout, "Note: this version of vtysh never writes vtysh.conf\n");
- /* If integrated Quagga.conf explicitely set. */
+ /* If integrated Frr.conf explicitely set. */
if (want_config_integrated())
{
ret = CMD_WARNING;
diff --git a/vtysh/vtysh_main.c b/vtysh/vtysh_main.c
index 127cb70ad..49aedae32 100644
--- a/vtysh/vtysh_main.c
+++ b/vtysh/vtysh_main.c
@@ -140,7 +140,7 @@ usage (int status)
fprintf (stderr, "Try `%s --help' for more information.\n", progname);
else
printf ("Usage : %s [OPTION...]\n\n" \
- "Integrated shell for Quagga routing software suite. \n\n" \
+ "Integrated shell for FRR. \n\n" \
"-b, --boot Execute boot startup configuration\n" \
"-c, --command Execute argument as command\n" \
"-d, --daemon Connect only to the specified daemon\n" \
@@ -151,7 +151,7 @@ usage (int status)
"-m, --markfile Mark input file with context end\n" \
" --vty_socket Override vty socket path\n" \
" --config_dir Override config directory path\n" \
- "-w, --writeconfig Write integrated config (Quagga.conf) and exit\n" \
+ "-w, --writeconfig Write integrated config (Frr.conf) and exit\n" \
"-h, --help Display this help and exit\n\n" \
"Note that multiple commands may be executed from the command\n" \
"line by passing multiple -c args, or by embedding linefeed\n" \
@@ -355,7 +355,7 @@ main (int argc, char **argv, char **env)
strlcat(vtysh_config_always, vtysh_configfile_name,
sizeof(vtysh_config_always));
/*
* Overwrite location for Quagga.conf
*/
vtysh_configfile_name = strrchr(FRR_DEFAULT_CONFIG, '/');
if (vtysh_configfile_name)
@@ -355,7 +355,7 @@ main (int argc, char **argv, char **env)
sizeof(vtysh_config_always));
/*
- * Overwrite location for Quagga.conf
+ * Overwrite location for Frr.conf
*/
vtysh_configfile_name = strrchr(FRR_DEFAULT_CONFIG, '/');